#!/usr/bin/env python

"""
UART example layout
v4

Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import serial
import easyterm_api
import configparser
config = configparser.ConfigParser(inline_comment_prefixes="#")
config.read('config.ini')

with serial.Serial(config['COM']['CFG_COM_PORT'], int(config['COM']['CFG_BAUD_RATE']), timeout=float(config['COM']['CFG_REPLY_TIMEOUT'])) as ser:    
    et = easyterm_api.EasyTermApi(ser)
    
    #Uncomment to reset
    #et.soft_reset()
    
    #Clear current screen page to make sure there is space for widgets
    et.clear_screen_page()
    
    #Header
    et.transceive('dg x=60 y=5 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    et.transceive('dt a=c x=160 y=10 t="UART" f=18b;', echo=True)
    et.transceive('dg x=60 y=30 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    
    #Init
    et.transceive('db x=125 y=38 c=0,0,100 w=70 h=30 t="Init" a="UART i=1" id=0;', echo=True)
    
    #Baud-rate
    et.transceive('dt x=40 y=70 bw=70 t="Frequency" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=86 c=0,0,100 w=70 h=40 t="38400" a="UART br=%d+eb id=1 t=\\"%_\\"" id=1;', echo=True)
    
    #TX inversion
    et.transceive('dt x=140 y=70 bw=108 t="TX inversion" a=c ld=l;', echo=True)
    et.transceive('dc x=85 y=86 w=55 h=40 ta="UART txi=0+ec id=1 s=0" ua="ec id=0 s=1" t="Disabled" s=1 is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=0;', echo=True)
    et.transceive('dc x=140 y=86 w=55 h=40 ta="UART txi=1+ec id=0 s=0" ua="ec id=1 s=1" t="Enabled" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=1;', echo=True)
    
    #RX inversion
    et.transceive('dt x=260 y=70 bw=108 t="RX inversion" a=c ld=l;', echo=True)
    et.transceive('dc x=205 y=86 w=55 h=40 ta="UART rxi=0+ec id=3 s=0" ua="ec id=2 s=1" t="Disabled" s=1 is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=2;', echo=True)
    et.transceive('dc x=260 y=86 w=55 h=40 ta="UART rxi=1+ec id=2 s=0" ua="ec id=3 s=1" t="Enabled" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=3;', echo=True)
    
    
    #Word length
    et.transceive('dt x=40 y=130 bw=70 t="Word length" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=146 c=0,0,100 w=70 h=40 t="8|7|9" a="UART wl=8|UART wl=7|UART wl=9" id=2;', echo=True)

    #MSb first
    et.transceive('dt x=140 y=130 bw=108 t="MSb first" a=c ld=l;', echo=True)
    et.transceive('dc x=85 y=146 w=55 h=40 ta="UART msbf=0+ec id=5 s=0" ua="ec id=4 s=1" t="Disabled" s=1 is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=4;', echo=True)
    et.transceive('dc x=140 y=146 w=55 h=40 ta="UART msbf=1+ec id=4 s=0" ua="ec id=5 s=1" t="Enabled" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=5;', echo=True)

    #Parity
    et.transceive('dt x=260 y=130 bw=108 t="Parity" a=c ld=l;', echo=True)
    et.transceive('dc x=205 y=146 w=55 h=40 ta="UART p=e+ec id=7 s=0" ua="UART p=n" t="Even" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=6;', echo=True)
    et.transceive('dc x=260 y=146 w=55 h=40 ta="UART p=o+ec id=6 s=0" ua="UART p=n" t="Odd" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=7;', echo=True)

    
    #Stop bits
    et.transceive('dt x=40 y=190 bw=70 t="Stop bits" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=206 c=0,0,100 w=70 h=40 t="1|0.5|1.5|2" a="UART sb=1|UART sb=0.5|UART sb=1.5|UART sb=2" id=3;', echo=True)
    
    #RX timeout
    et.transceive('dt x=140 y=190 bw=108 t="RX timeout" a=c ld=l;', echo=True)
    et.transceive('db x=85 y=206 c=0,0,100 w=110 h=40 t="1000" a="UART rxt=%d+eb id=4 t=\\"%_\\"" id=4;', echo=True)
    
    #Read format
    et.transceive('dt x=260 y=190 bw=108 t="Read format" a=c ld=l;', echo=True)
    et.transceive('db x=205 y=206 c=0,0,100 w=110 h=40 t="0x1" a="UART rf=\\"%s\\"+eb id=5 t=\\"%_\\"" id=5;', echo=True)
    
    
    et.transceive('dt x=160 y=249 bw=224 t="Transmit/receive" a=c ld=l;', echo=True)
    #Transmit bytes
    et.transceive('db x=48 y=265 c=0,0,100 w=111 h=40 t="Transmit bytes" a="UART tx=%x";', echo=True)
    
    #Transmit ASCII
    et.transceive('db x=161 y=265 c=0,0,100 w=110 h=40 t="Transmit ASCII" a="UART tx=\\"%s\\"";', echo=True)
    
    #Receive
    et.transceive('db x=48 y=307 c=0,0,100 w=111 h=40 t="Receive" a="UART rx=%d";', echo=True)
    
    #Background receive
    et.transceive('db x=161 y=307 c=0,0,100 w=110 h=40 t="Background receive" a="UART brx=%d";', echo=True)
    
    #Transmit bytes and receive
    et.transceive('db x=48 y=349 c=0,0,100 w=224 h=40 t="Transmit bytes and receive" a="UART txrx=%x,%d";', echo=True)
    
    #Transmit ASCII and receive
    et.transceive('db x=48 y=391 c=0,0,100 w=224 h=40 t="Transmit ASCII and receive" a="UART txrx=\\"%s\\",%d";', echo=True)
    
    #RX command replies form
    et.transceive('df x=0 y=433 w=320 h=30 t="- RX data -" pm="UART rx=%s\\r\\n";', echo=True)
    
    #EasyTerm replies form
    et.transceive('dg x=10 y=463 w=300 h=1 c=50,50,50;', echo=True)
    et.transceive('df x=0 y=465 w=320 h=15 ft=vo pm="%s\\r\\n";', echo=True)

    #Uncomment to save layout in flash and recover after device startup
    #et.transceive('sl bid=0;', echo=True, custom_timeout=2)
    #et.transceive('sys coi="ll bid=0";', echo=True, custom_timeout=2)
    
